summaryrefslogtreecommitdiffstats
path: root/lib/Fetcher/Fetcher.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Fetcher/Fetcher.php')
-rw-r--r--lib/Fetcher/Fetcher.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/lib/Fetcher/Fetcher.php b/lib/Fetcher/Fetcher.php
index 23f5b57f7..425004680 100644
--- a/lib/Fetcher/Fetcher.php
+++ b/lib/Fetcher/Fetcher.php
@@ -13,6 +13,8 @@
namespace OCA\News\Fetcher;
+use FeedIo\Reader\ReadErrorException;
+
class Fetcher
{
@@ -48,7 +50,7 @@ class Fetcher
* @param string $user if given, basic auth is set for this feed
* @param string $password if given, basic auth is set for this feed. Ignored if user is empty
*
* @throws FetcherException if FeedIO fails
* @return array an array containing the new feed and its items, first
* element being the Feed and second element being an array of Items
*/
@@ -48,7 +50,7 @@ class Fetcher
* @param string $password if given, basic auth is set for this feed. Ignored if user is empty
*
- * @throws FetcherException if FeedIO fails
+ * @throws ReadErrorException if FeedIO fails
* @return array an array containing the new feed and its items, first
* element being the Feed and second element being an array of Items